golang

package
v1.5.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2023 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateVektraMocks

func GenerateVektraMocks() error

GenerateVektraMocks creates mock files via vektra/mockery

func RunBuildBinary added in v1.5.14

func RunBuildBinary(binName string) error

RunBuildBinary triggers go build for main package in repository root

func RunBuildBinaryFromDir added in v1.5.14

func RunBuildBinaryFromDir(binName, dir string) error

RunBuildBinaryFromDir triggers go build for package in specified dir

func RunLint added in v1.5.14

func RunLint() error

RunLint runs go lint for all modules

func RunTest added in v1.5.14

func RunTest() error

RunTest runs go test for all modules

func RunVet added in v1.5.14

func RunVet() error

RunVet runs go vet for all modules

Types

This section is empty.

Jump to